# Collibra Integration
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/collibra-integration#overview)
  * [Benefits](https://help.sap.com/docs/leanix/ea/collibra-integration#benefits)
  * [Scope of Integration: Data Synchronization Between Collibra and SAP LeanIX](https://help.sap.com/docs/leanix/ea/collibra-integration#scope-of-integration:-data-synchronization-between-collibra-and-sap-leanix)
  * [Best Practices and Essential Concepts](https://help.sap.com/docs/leanix/ea/collibra-integration#best-practices-and-essential-concepts)
  * [Define the Sync Scope](https://help.sap.com/docs/leanix/ea/collibra-integration#define-the-sync-scope)
  * [Establish Clear Sources of Truth](https://help.sap.com/docs/leanix/ea/collibra-integration#establish-clear-sources-of-truth)
  * [Focus on the Conceptual Data Layer](https://help.sap.com/docs/leanix/ea/collibra-integration#focus-on-the-conceptual-data-layer)
  * [Create A Dedicated User Account for Integration](https://help.sap.com/docs/leanix/ea/collibra-integration#create-a-dedicated-user-account-for-integration)


View all
The integration between SAP LeanIX and Collibra enhances data governance by aligning enterprise and data architecture. With increased transparency and accessibility, stakeholders can make informed decisions on data management and compliance.
